import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';

Vue.use(VueRouter);

const index = [
  {
    path: '/index',
    name: 'index',
    meta: { title: '首页' },
    component: () => import(/* webpackChunkName: "index" */ '../views/index/index.vue'),
  },
  {
    path: '/index2',
    name: 'index2',
    meta: { title: '首页' },
    component: () => import(/* webpackChunkName: "index" */ '../views/index/index2.vue'),
  },
];
const space = [
  {
    path: '/space/sindex',
    name: 'space_sindex',
    meta: { title: '样式选择' },
    component: () => import(/* webpackChunkName: "space_sindex" */ '../views/space/sindex.vue'),
  },
  {
    path: '/space',
    name: 'space',
    meta: { title: '预定场地' },
    component: () => import(/* webpackChunkName: "space" */ '../views/space/space.vue'),
  },
  {
    path: '/space2',
    name: 'space2',
    meta: { title: '预定场地2' },
    component: () => import(/* webpackChunkName: "space2" */ '../views/space/space2.vue'),
  },
  {
    path: '/space/submit',
    name: 'space_submit',
    meta: { title: '提交预定' },
    component: () => import(/* webpackChunkName: "space_submit" */ '../views/space/submit.vue'),
  },
  {
    path: '/space/success',
    name: 'space_success',
    meta: { title: '支付成功' },
    component: () => import(/* webpackChunkName: "space_success" */ '../views/space/success.vue'),
  },
  {
    path: '/space/error',
    name: 'space_error',
    meta: { title: '支付失败' },
    component: () => import(/* webpackChunkName: "space_error" */ '../views/space/error.vue'),
  },
];
const order = [
  {
    path: '/order',
    name: 'order',
    meta: { title: '订单页面' },
    component: () => import(/* webpackChunkName: "order" */ '../views/order/index.vue'),
  },
  {
    path: '/order/detail',
    name: 'order_detail',
    meta: { title: '订单详情' },
    component: () => import(/* webpackChunkName: "order_detail" */ '../views/order/detail.vue'),
  },
  {
    path: '/order/refund',
    name: 'order_refund',
    meta: { title: '退款' },
    component: () => import(/* webpackChunkName: "order_refund" */ '../views/order/refund.vue'),
  },
];
const self = [
  {
    path: '/self',
    name: 'self',
    meta: { title: '个人中心' },
    component: () => import(/* webpackChunkName: "self" */ '../views/self/index.vue'),
  },
  {
    path: '',
    component: () => import(/* webpackChunkName: "client" */ '../layout/client.vue'),
    children: [
      // 教练
      {
        path: '/self/becoach',
        name: 'becoach',
        meta: { title: '成为教练' },
        component: () => import(/* webpackChunkName: "becoach" */ '../views/self/train/be-coach.vue'),
      },
      {
        path: '/self/teach',
        name: 'cocah_teach',
        meta: { title: '上报时间' },
        component: () => import(/* webpackChunkName: "cocah_teach" */ '../views/self/train/teach.vue'),
      },
      {
        path: '/self/schedule',
        name: 'cocah_schedule',
        meta: { title: '日程表' },
        component: () => import(/* webpackChunkName: "cocah_schedule" */ '../views/self/train/schedule.vue'),
      },
      // 学员
      {
        path: '/self/student/cocah',
        name: 'student_cocah',
        meta: { title: '选择教练' },
        component: () => import(/* webpackChunkName: "student_cocah" */ '../views/self/student/index.vue'),
      },
      {
        path: '/self/student/space',
        name: 'student_space',
        meta: { title: '选择场地' },
        component: () => import(/* webpackChunkName: "student_space" */ '../views/self/student/space.vue'),
      },
      {
        path: '/self/student/pay',
        name: 'student_pay',
        meta: { title: '支付费用' },
        component: () => import(/* webpackChunkName: "student_pay" */ '../views/self/student/pay.vue'),
      },
      // 基本信息
      {
        path: '/self/basic/index',
        meta: { title: '基本信息' },
        component: () => import(/* webpackChunkName: "self" */ '../views/self/basic/index.vue'),
      },
      // 会员相关
      {
        path: '/self/member/become',
        meta: { title: '成为会员' },
        component: () => import('../views/self/member/become.vue'),
      },
      {
        path: '/self/member/recharge',
        meta: { title: '会员充值' },
        component: () => import('../views/self/member/recharge.vue'),
      },
      {
        path: '/self/member/backlog',
        meta: { title: '待办会员' },
        component: () => import('../views/self/member/backlog.vue'),
      },
      {
        path: '/self/member/backlogQrcode',
        meta: { title: '会员信息' },
        component: () => import('../views/self/member/backlogQrcode.vue'),
      },
      {
        path: '/self/member/invitation',
        meta: { title: '邀请码' },
        component: () => import('../views/self/member/invitation.vue'),
      },
      // 商城
      {
        path: '/self/purchase/index',
        meta: { title: '我的购买' },
        component: () => import('../views/self/purchase/index.vue'),
      },
    ],
  },
  // 特殊预约
  {
    path: '/self/subscribe/index',
    meta: { title: '特殊预约' },
    component: () => import('../views/self/subscribe/index.vue'),
  },
];
const shop = [
  {
    path: '/shop',
    name: 'shop_index',
    meta: { title: '精选商店' },
    component: () => import(/* webpackChunkName: "shop_index" */ '../views/shop/index.vue'),
  },
];
const routes = [
  {
    path: '/',
    name: 'Home',
    component: () => import(/* webpackChunkName: "Home" */ '../views/Home.vue'),
  },
  {
    path: '/login',
    name: 'login',
    component: () => import(/* webpackChunkName: "login" */ '../views/login.vue'),
  },
  {
    path: '/client',
    component: () => import(/* webpackChunkName: "client" */ '../layout/client.vue'),
    children: [
      // 场地
      ...space,
      // 订单
      ...order,
      // 首页
      ...index,
      // 商店
      ...shop,
    ],
  },
  // 个人中心
  ...self,
];

const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});

router.beforeEach((to, form, next) => {
  const user = sessionStorage.getItem('user');
  if (user) {
    store.commit('setUser', JSON.parse(user), { root: true });
  }
  next();
});
export default router;
